@@ -91,7 +91,9 @@ class BaseModelConfig:
     - Data preprocessing (missing data handling)
     
     Series Configuration:
-    - Provide `frequency` dict: {'column_name': 'frequency_code'} to specify per-series frequencies
+    - Provide `frequency` dict in one of two formats:
+      1. Grouped format: {'w': [series1, series2, ...], 'm': [series3, ...]} (recommended for large configs)
+      2. Individual format: {'series1': 'w', 'series2': 'm', ...} (backward compatible)
     - If `frequency` is None, all columns will use `clock` frequency
     - If a column is missing from `frequency` dict, it will use `clock` frequency
     - When data is loaded, missing columns in `frequency` dict are automatically added with `clock` frequency
@@ -103,7 +105,14 @@ class BaseModelConfig:
     
     Examples
     --------
-    >>> # With explicit frequency mapping
+    >>> # With grouped frequency mapping (recommended for large configs)
+    >>> config = DFMConfig(
+    ...     frequency={'q': ['gdp'], 'm': ['unemployment', 'interest_rate']},
+    ...     clock='m',
+    ...     blocks={...}
+    ... )
+    >>> 
+    >>> # With individual frequency mapping (backward compatible)
     >>> config = DFMConfig(
     ...     frequency={'gdp': 'q', 'unemployment': 'm', 'interest_rate': 'm'},
     ...     clock='m',
@@ -277,12 +286,19 @@ class DFMConfig(BaseModelConfig):
     # Damped Updates: If provided (not None), automatically enables damping and always warns
     damping_factor: Optional[float] = None  # Damping factor (0.8 = 80% new, 20% old). If None, no damping. If provided, damping enabled and warnings always shown.
     
-    # Idiosyncratic Component Parameters (auto-detected from frequencies)
+    # Idiosyncratic Component Parameters
     idio_rho0: float = DEFAULT_IDIO_RHO0  # Initial AR coefficient for idiosyncratic components (default: 0.1)
     idio_min_var: float = MIN_DIAGONAL_VARIANCE  # Minimum variance for idiosyncratic innovation covariance (defaults to MIN_DIAGONAL_VARIANCE)
-    # Note: augment_idio and augment_idio_slow are auto-detected from frequency configuration
+    # Note: augment_idio and augment_idio_slow are INTERNALLY auto-detected (not configurable)
     # - If all series use clock frequency: augment_idio=False, augment_idio_slow=False
-    # - If mixed frequencies detected: augment_idio=True, augment_idio_slow=True (auto-enabled)
+    # - If mixed frequencies detected: augment_idio=True, augment_idio_slow=True (required for tent kernel)
+    # These are properties, not config fields - automatically determined from frequency configuration
+    
+    # Kalman Filter Type
+    use_cholesky_filter: bool = False  # Use CholeskyKalmanFilter for better numerical stability (default: False)
+    
+    # Tent Kernel Weights (for mixed-frequency aggregation)
+    tent_weights: Optional[Union[Dict[str, List[float]], Dict[str, np.ndarray]]] = None  # Required for mixed-frequency data: tent weights for frequency pairs. Format: {'freq_pair': [weights]} or {'freq': [weights]}. Example: {'m:w': [1, 2, 1]} or {'m': [1, 2, 1]}. Must be specified in config for all slower-frequency pairs.
     
     def __post_init__(self):
         """Validate blocks structure and derive block properties."""
@@ -437,6 +453,8 @@ class DFMConfig(BaseModelConfig):
             'data_clip': data.get('data_clip', None),
             'regularization': data.get('regularization', None),
             'damping_factor': data.get('damping_factor', None),
+            'use_cholesky_filter': data.get('use_cholesky_filter', False),
+            'tent_weights': data.get('tent_weights', None),
         }
         
         result = base_params.copy()
@@ -515,6 +533,11 @@ class DDFMConfig(BaseModelConfig):
     seed: Optional[int] = None  # Random seed for reproducibility
     lags_input: int = 0  # Number of lags of inputs on encoder (default 0, matching original TensorFlow DDFM)
     
+    # Interpolation parameters (for handling missing values)
+    interpolation_method: str = 'linear'  # Interpolation method: 'linear', 'spline', 'cubic', etc. (default: 'linear' for stability)
+    interpolation_limit: Optional[int] = 10  # Maximum consecutive NaNs to interpolate (default: 10, prevents extreme extrapolation)
+    interpolation_limit_direction: str = 'both'  # Direction to fill: 'forward', 'backward', or 'both' (default: 'both')
+    
     
     # ========================================================================
     # Factory Methods
@@ -541,6 +564,9 @@ class DDFMConfig(BaseModelConfig):
             'disp': DEFAULT_DISP,
             'seed': None,
             'lags_input': 0,  # Number of lags (default 0, matching original TensorFlow)
+            'interpolation_method': 'linear',  # Interpolation method (default: 'linear' for stability)
+            'interpolation_limit': 10,  # Maximum consecutive NaNs to interpolate (default: 10)
+            'interpolation_limit_direction': 'both',  # Direction to fill (default: 'both')
         })
         # Map 'epochs' from config to 'n_mc_samples' for clarity (backward compatibility)
         # Always remove 'epochs' if present (even if n_mc_samples is also present)
