@@ -2,8 +2,7 @@
 
 import pytest
 from torch.utils.data import DataLoader
-from dfm_python.dataset.dataset import DDFMDataset
-import numpy as np
+from dfm_python.dataset.ddfm_dataset import DDFMDataset
 
 
 class TestDataLoader:
@@ -11,8 +10,14 @@ class TestDataLoader:
     
     def test_dataloader_initialization(self, sample_data):
         """Test DataLoader can be initialized with DDFMDataset."""
-        data_array = sample_data.values.astype(np.float32)
-        dataset = DDFMDataset(data_array, window_size=10)
+        # Use current DDFMDataset API: data (DataFrame), time_idx, target_series, target_scaler
+        target_series = list(sample_data.columns)
+        dataset = DDFMDataset(
+            data=sample_data,
+            time_idx=sample_data.index.name or 'index',
+            target_series=target_series,
+            target_scaler=None
+        )
         dataloader = DataLoader(dataset, batch_size=4, shuffle=False)
         assert dataloader is not None
         assert dataloader.batch_size == 4
